@@ -30,9 +30,9 @@
     (let [mock-diagnostics-chan (async/chan 1)]
       (h/load-code-and-locs "(ns a) (when)" h/default-uri (assoc (h/components)
                                                                  :diagnostics-chan mock-diagnostics-chan))
-      (is (some? (get-in (h/db) [:analysis (h/file-path "/a.clj")])))
+      (is (some? (get-in (h/db) [:analysis (h/file-uri "file:///a.clj")])))
       (let [{:keys [uri diagnostics]} (h/take-or-timeout mock-diagnostics-chan 500)]
-        (is (= "file:///a.clj" uri))
+        (is (= (h/file-uri "file:///a.clj") uri))
         (h/assert-submaps
           [{:code "missing-body-in-when"}
            {:code "invalid-arity"}]
@@ -51,7 +51,7 @@
                            :end {:line 999998, :character 999998}}
                    :new-text "(ns foo.bar)"}]}]
         (:document-changes (h/take-or-timeout mock-edits-chan 500)))
-      (is (some? (get-in (h/db) [:analysis (h/file-path "/project/src/foo/bar.clj")])))))
+      (is (some? (get-in (h/db) [:analysis (h/file-uri "file:///project/src/foo/bar.clj")])))))
   (testing "opening a new edn file not adding the ns"
     (h/reset-components!)
     (swap! (h/db*) merge {:settings {:auto-add-ns-to-new-files? true
@@ -62,36 +62,36 @@
       (h/load-code-and-locs "" (h/file-uri "file:///project/src/foo/baz.edn") (assoc (h/components)
                                                                                      :edits-chan mock-edits-chan))
       (h/assert-no-take mock-edits-chan 500)
-      (is (some? (get-in (h/db) [:analysis (h/file-path "/project/src/foo/baz.edn")]))))))
+      (is (some? (get-in (h/db) [:analysis (h/file-uri "file:///project/src/foo/baz.edn")]))))))
 
 (deftest document-symbol
   (let [code "(ns a) (def bar ::bar) (def ^:m baz 1) (defmulti mult identity) (defmethod mult \"foo\")"
-        result [{:name "a"
-                 :kind :namespace
-                 :range {:start {:line 0 :character 0} :end {:line 999999 :character 999999}}
-                 :selection-range {:start {:line 0 :character 0} :end {:line 0 :character 6}}
-                 :children [{:name "bar"
-                             :kind :variable
-                             :range {:start {:line 0 :character 7} :end {:line 0 :character 22}}
-                             :selection-range {:start {:line 0 :character 12} :end {:line 0 :character 15}}
-                             :tags []}
-                            {:name "baz"
-                             :kind :variable
-                             :range {:start {:line 0 :character 23} :end {:line 0 :character 38}}
-                             :selection-range {:start {:line 0 :character 32} :end {:line 0 :character 35}}
-                             :tags []}
-                            ;; defmulti
-                            {:name "mult",
-                             :kind :variable,
-                             :range {:start {:line 0, :character 39}, :end {:line 0, :character 63}},
-                             :selection-range {:start {:line 0, :character 49}, :end {:line 0, :character 53}}
-                             :tags []}
-                            ;; defmethod
-                            {:name "mult \"foo\"",
-                             :kind :variable,
-                             :range {:start {:line 0, :character 75}, :end {:line 0, :character 79}},
-                             :selection-range {:start {:line 0, :character 75}, :end {:line 0, :character 79}}
-                             :tags []}]}]]
+        result #{{:name "a"
+                  :kind :namespace
+                  :range {:start {:line 0 :character 0} :end {:line 999999 :character 999999}}
+                  :selection-range {:start {:line 0 :character 0} :end {:line 0 :character 6}}
+                  :children [{:name "bar"
+                              :kind :variable
+                              :range {:start {:line 0 :character 7} :end {:line 0 :character 22}}
+                              :selection-range {:start {:line 0 :character 12} :end {:line 0 :character 15}}
+                              :tags []}
+                             {:name "baz"
+                              :kind :variable
+                              :range {:start {:line 0 :character 23} :end {:line 0 :character 38}}
+                              :selection-range {:start {:line 0 :character 32} :end {:line 0 :character 35}}
+                              :tags []}
+                               ;; defmulti
+                             {:name "mult",
+                              :kind :variable,
+                              :range {:start {:line 0, :character 39}, :end {:line 0, :character 63}},
+                              :selection-range {:start {:line 0, :character 49}, :end {:line 0, :character 53}}
+                              :tags []}
+                               ;; defmethod
+                             {:name "mult \"foo\"",
+                              :kind :variable,
+                              :range {:start {:line 0, :character 75}, :end {:line 0, :character 79}},
+                              :selection-range {:start {:line 0, :character 75}, :end {:line 0, :character 79}}
+                              :tags []}]}}]
     (testing "clj files"
       (h/load-code-and-locs code)
       (h/assert-submaps result
@@ -130,10 +130,10 @@
     (let [[bar-def-pos] (h/load-code-and-locs "(ns a) (def |bar 1)")
           _ (h/load-code-and-locs "(ns b (:require [a :as foo])) (foo/bar)" (h/file-uri "file:///b.clj"))]
       (h/assert-submaps
-        [{:uri (h/file-uri "file:///a.clj")
-          :range {:start {:line 0 :character 12} :end {:line 0 :character 15}}}
-         {:uri (h/file-uri "file:///b.clj")
-          :range {:start {:line 0 :character 31} :end {:line 0 :character 38}}}]
+        #{{:uri (h/file-uri "file:///a.clj")
+           :range {:start {:line 0 :character 12} :end {:line 0 :character 15}}}
+          {:uri (h/file-uri "file:///b.clj")
+           :range {:start {:line 0 :character 31} :end {:line 0 :character 38}}}}
         (handlers/references (h/components)
                              {:text-document {:uri (h/file-uri "file:///a.clj")}
                               :position (h/->position bar-def-pos)
